##  Linking IT Components to Catalog Items
**Note**
Both admins and members can manage how fact sheets are linked to catalog items, which includes establishing links, ignoring fact sheets, and modifying existing links. Viewers don't have access to the reference catalog.
When a fact sheet is linked to a catalog item, the attributes selected by the admin are automatically synced with the catalog and regularly updated.
There are three ways to link fact sheets to the catalog:
  * Bulk linking fact sheets from the inventory
  * Linking individual fact sheets from the fact sheet page
  * Linking a fact sheet during fact sheet creation


On the Last Update tab of the fact sheet, you can check any updates made to the linked fact sheet as a result of syncing. Updates done are attributed to the System user ‘reference data’ user.
